package com.landray.kmss.sys.attachment.actions;

import com.landray.kmss.web.config.IActionConfig;
import java.util.Map;
import com.landray.kmss.web.config.ForwardConfig;
import com.landray.kmss.common.exception.KmssException;
import com.landray.kmss.util.KmssMessage;
import com.landray.kmss.sys.filestore.forms.SysAttCatalogForm;
import java.util.List;
import com.landray.kmss.util.KmssReturnPage;
import org.springframework.util.StringUtils;
import com.landray.kmss.util.HQLUtil;
import java.util.ArrayList;
import com.landray.kmss.common.exception.UnexpectedRequestException;
import com.landray.kmss.util.KmssMessages;
import com.landray.kmss.common.test.TimeCounter;
import com.landray.kmss.web.action.ActionForward;
import javax.servlet.http.HttpServletResponse;
import com.landray.kmss.web.action.ActionForm;
import com.landray.kmss.web.action.ActionMapping;
import com.landray.kmss.util.CriteriaUtil;
import com.landray.kmss.sys.filestore.model.SysAttCatalog;
import com.landray.kmss.util.CriteriaValue;
import com.landray.kmss.util.StringUtil;
import com.landray.kmss.common.dao.HQLInfo;
import com.landray.kmss.common.service.IBaseService;
import javax.servlet.http.HttpServletRequest;
import com.landray.kmss.sys.filestore.service.ISysAttCatalogService;
import com.landray.kmss.common.actions.ExtendAction;

public class SysAttCatalogAction extends ExtendAction
{
    protected ISysAttCatalogService sysAttCatalogService;
    
    protected IBaseService getServiceImp(final HttpServletRequest request) {
        if (this.sysAttCatalogService == null) {
            this.sysAttCatalogService = (ISysAttCatalogService)this.getBean("sysAttCatalogService");
        }
        return (IBaseService)this.sysAttCatalogService;
    }
    
    protected void changeFindPageHQLInfo(final HttpServletRequest request, final HQLInfo hqlInfo) throws Exception {
        super.changeFindPageHQLInfo(request, hqlInfo);
        String whereBlock = hqlInfo.getWhereBlock();
        if (StringUtil.isNull(whereBlock)) {
            whereBlock = "1=1 ";
        }
        final CriteriaValue cv = new CriteriaValue(request);
        CriteriaUtil.buildHql(cv, hqlInfo, (Class)SysAttCatalog.class);
    }
    
    public ActionForward deleteall(final ActionMapping mapping, final ActionForm form, final HttpServletRequest request, final HttpServletResponse response) throws Exception {
        TimeCounter.logCurrentTime("Action-deleteall", true, (Class)this.getClass());
        final KmssMessages messages = new KmssMessages();
        boolean jumpToConfirm = false;
        try {
            if (!"POST".equals(request.getMethod())) {
                throw new UnexpectedRequestException();
            }
            final String[] ids = request.getParameterValues("List_Selected");
            if (ids != null && ids.length > 0) {
                final List selectUsedList = new ArrayList();
                final HQLInfo info = new HQLInfo();
                info.setSelectBlock("distinct sysAttFile.fdCata.fdId");
                info.setModelName("SysAttFile");
                final List usedList = this.sysAttCatalogService.findValue(info);
                if (!usedList.isEmpty()) {
                    for (int i = 0; i < ids.length; ++i) {
                        if (usedList.contains(ids[i])) {
                            selectUsedList.add(ids[i]);
                            jumpToConfirm = true;
                        }
                        else {
                            this.sysAttCatalogService.delete(ids[i]);
                        }
                    }
                }
                else {
                    this.sysAttCatalogService.delete(ids);
                }
                if (!selectUsedList.isEmpty()) {
                    final HQLInfo hqlInfo = new HQLInfo();
                    hqlInfo.setSelectBlock(" sysAttCatalog.fdId ,sysAttCatalog.fdName , COUNT(sysAttCatalog.fdId) ");
                    hqlInfo.setFromBlock("SysAttCatalog sysAttCatalog , SysAttFile sysAttFile ");
                    hqlInfo.setWhereBlock("sysAttCatalog.fdId = sysAttFile.fdCata.fdId and " + HQLUtil.buildLogicIN("sysAttCatalog.fdId", selectUsedList) + " group by sysAttCatalog.fdId,sysAttCatalog.fdName ");
                    final List deletingList = this.sysAttCatalogService.findValue(hqlInfo);
                    request.setAttribute("currentIds", (Object)StringUtils.arrayToDelimitedString(selectUsedList.toArray(), ";"));
                    request.setAttribute("deletingList", (Object)deletingList);
                }
            }
        }
        catch (final Exception e) {
            messages.addError((Throwable)e);
        }
        TimeCounter.logCurrentTime("Action-deleteall", false, (Class)this.getClass());
        if (messages.hasError()) {
            KmssReturnPage.getInstance(request).addMessages(messages).addButton(1).save(request);
            return this.getActionForward("failure", mapping, form, request, response);
        }
        if (jumpToConfirm) {
            return this.getActionForward("confirm", mapping, form, request, response);
        }
        KmssReturnPage.getInstance(request).addMessages(messages).addButton(1).save(request);
        return this.getActionForward("success", mapping, form, request, response);
    }
    
    public ActionForward updateCataFile(final ActionMapping mapping, final ActionForm form, final HttpServletRequest request, final HttpServletResponse response) throws Exception {
        TimeCounter.logCurrentTime("Action-updateCurrent", true, (Class)this.getClass());
        int updated = 0;
        int deleted = 0;
        final KmssMessages messages = new KmssMessages();
        try {
            if (!"POST".equals(request.getMethod())) {
                throw new UnexpectedRequestException();
            }
            final SysAttCatalogForm catalogForm = (SysAttCatalogForm)form;
            final List checkIds = catalogForm.getCheckIds();
            final List changeIds = catalogForm.getChangeIds();
            if (checkIds.size() != changeIds.size()) {
                throw new KmssException(messages.addError(new KmssMessage("sys-attachment:sysAttCatalog.updateCataFile.error")));
            }
            for (int i = 0; i < checkIds.size(); ++i) {
                final String chkId = checkIds.get(i);
                final String chgId = changeIds.get(i);
                final String updateHql = "update SysAttFile sysAttFile set sysAttFile.fdCata.fdId=:chgId where sysAttFile.fdCata.fdId=:chkId";
                updated += this.sysAttCatalogService.getBaseDao().getHibernateSession().createQuery(updateHql).setParameter("chgId", (Object)chgId).setParameter("chkId", (Object)chkId).executeUpdate();
            }
            deleted = this.sysAttCatalogService.getBaseDao().getHibernateSession().createQuery("delete from SysAttCatalog sysAttCatalog where " + HQLUtil.buildLogicIN("sysAttCatalog.fdId", checkIds)).executeUpdate();
            messages.addMsg(new KmssMessage("sys-attachment:sysAttCatalog.updateCataFile.info", (Object)updated, (Object)deleted));
        }
        catch (final Exception e) {
            messages.addError((Throwable)e);
        }
        KmssReturnPage.getInstance(request).addMessages(messages).addButton(0).save(request);
        TimeCounter.logCurrentTime("Action-updateCurrent", false, (Class)this.getClass());
        if (messages.hasError()) {
            return this.getActionForward("failure", mapping, form, request, response);
        }
        return this.getActionForward("success", mapping, form, request, response);
    }
    
    public ActionForward updateCurrent(final ActionMapping mapping, final ActionForm form, final HttpServletRequest request, final HttpServletResponse response) throws Exception {
        TimeCounter.logCurrentTime("Action-updateCurrent", true, (Class)this.getClass());
        final KmssMessages messages = new KmssMessages();
        try {
            if (!"POST".equals(request.getMethod())) {
                throw new UnexpectedRequestException();
            }
            final String[] ids = request.getParameterValues("List_Selected");
            if (ids != null && ids.length > 0) {
                if (ids.length > 1) {
                    throw new KmssException(messages.addError(new KmssMessage("sys-attachment:sysAttCatalog.update.error")));
                }
                this.sysAttCatalogService.updateCurrent(ids[0]);
            }
        }
        catch (final Exception e) {
            messages.addError((Throwable)e);
        }
        KmssReturnPage.getInstance(request).addMessages(messages).addButton(1).save(request);
        TimeCounter.logCurrentTime("Action-updateCurrent", false, (Class)this.getClass());
        if (messages.hasError()) {
            return this.getActionForward("failure", mapping, form, request, response);
        }
        return this.getActionForward("success", mapping, form, request, response);
    }
}
